#!/usr/bin/env rspec

# Copyright (c) [2021] SUSE LLC
#
# All Rights Reserved.
#
# This program is free software; you can redistribute it and/or modify it
# under the terms of version 2 of the GNU General Public License as published
# by the Free Software Foundation.
#
# This program is distributed in the hope that it will be useful, but WITHOUT
# ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
# FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
# more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, contact SUSE LLC.
#
# To contact SUSE LLC about this file by physical or electronic mail, you may
# find current contact information at www.suse.com.

require_relative "../spec_helper"
require "y2storage/dialogs/issues_details"

describe Y2Storage::Dialogs::IssuesDetails do
  before do
    allow(Yast::UI).to receive(:OpenDialog).and_return(true)
    allow(Yast::UI).to receive(:SetFocus)
    allow(Yast::UI).to receive(:CloseDialog)
    allow(Yast::UI).to receive(:UserInput).and_return(event, :ok)
  end

  subject { described_class.new(issues) }

  let(:issues) { Y2Issues::List.new }

  let(:event) { nil }

  describe ".show" do
    before do
      allow(Y2Storage::Widgets::Issues).to receive(:new).and_return(issues_widget)
    end

    let(:issues_widget) { Y2Storage::Widgets::Issues.new(id: "issues") }

    it "shows an issues widget" do
      expect(issues_widget).to receive(:content)

      subject.show
    end

    context "when the event is generated by the list of issues" do
      let(:event) { "issues" }

      it "delegates the event handling to the issues widget" do
        expect(issues_widget).to receive(:handle_event)

        subject.show
      end
    end

    context "when the event is not generated by the list of issues" do
      let(:event) { "other-widget" }

      it "does not delegate the event handling to the issues widget" do
        expect(issues_widget).to_not receive(:handle_event)

        subject.show
      end
    end
  end
end
